@@ -1,2 +1,2 @@
 from .functions import create_model, generate_sql, iv_feature_select, predict_proba, save_reports, \
-    sequential_feature_select, save_scorecard
+    sequential_feature_select, save_scorecard_fn
